@@ -8,6 +8,8 @@ from .const import (
     DEVICE_TYPE_PURE_COOL_DESK,
     DEVICE_TYPE_PURE_COOL_LINK,
     DEVICE_TYPE_PURE_COOL_LINK_DESK,
+    DEVICE_TYPE_PURE_HOT_COOL,
+    DEVICE_TYPE_PURE_HOT_COOL_LINK,
     DEVICE_TYPE_PURE_HUMIDITY_COOL,
 )
 from .const import DEVICE_TYPE_NAMES  # noqa: F401
@@ -19,6 +21,8 @@ from .dyson_360_eye import VacuumState  # noqa: F401
 from .dyson_device import DysonDevice
 from .dyson_pure_cool import DysonPureCool
 from .dyson_pure_cool_link import DysonPureCoolLink
+from .dyson_pure_hot_cool import DysonPureHotCool
+from .dyson_pure_hot_cool_link import DysonPureHotCoolLink
 
 
 def get_device(serial: str, credential: str, device_type: str) -> Optional[DysonDevice]:
@@ -36,4 +40,8 @@ def get_device(serial: str, credential: str, device_type: str) -> Optional[Dyson
         DEVICE_TYPE_PURE_HUMIDITY_COOL,
     ]:
         return DysonPureCool(serial, credential, device_type)
+    if device_type == DEVICE_TYPE_PURE_HOT_COOL_LINK:
+        return DysonPureHotCoolLink(serial, credential, device_type)
+    if device_type == DEVICE_TYPE_PURE_HOT_COOL:
+        return DysonPureHotCool(serial, credential, device_type)
     return None
